@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2012-2018 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -250,6 +250,183 @@ typedef enum {
 	GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_DISABLE	= 1 << 4,
 } GsPluginManageRepositoryFlags;
 
+/**
+ * GsPluginInstallAppsFlags:
+ * @GS_PLUGIN_INSTALL_APPS_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_INSTALL_APPS_FLAGS_INTERACTIVE: User initiated the job.
+ * @GS_PLUGIN_INSTALL_APPS_FLAGS_NO_DOWNLOAD: Only use locally cached resources,
+ *   and error if they don’t exist.
+ * @GS_PLUGIN_INSTALL_APPS_FLAGS_NO_APPLY: Only download the resources, and don’t
+ *   do the installation.
+ *
+ * Flags for an operation to download or install apps.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_INSTALL_APPS_FLAGS_NONE = 0,
+	GS_PLUGIN_INSTALL_APPS_FLAGS_INTERACTIVE = 1 << 0,
+	GS_PLUGIN_INSTALL_APPS_FLAGS_NO_DOWNLOAD = 1 << 1,
+	GS_PLUGIN_INSTALL_APPS_FLAGS_NO_APPLY = 1 << 2,
+} GsPluginInstallAppsFlags;
+
+/**
+ * GsPluginUninstallAppsFlags:
+ * @GS_PLUGIN_UNINSTALL_APPS_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_UNINSTALL_APPS_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for an operation to uninstall apps.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_UNINSTALL_APPS_FLAGS_NONE = 0,
+	GS_PLUGIN_UNINSTALL_APPS_FLAGS_INTERACTIVE = 1 << 0,
+} GsPluginUninstallAppsFlags;
+
+/**
+ * GsPluginUpdateAppsFlags:
+ * @GS_PLUGIN_UPDATE_APPS_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_UPDATE_APPS_FLAGS_INTERACTIVE: User initiated the job.
+ * @GS_PLUGIN_UPDATE_APPS_FLAGS_NO_DOWNLOAD: Only use locally cached resources,
+ *   and error if they don’t exist.
+ * @GS_PLUGIN_UPDATE_APPS_FLAGS_NO_APPLY: Only download the resources, and don’t
+ *   apply the updates.
+ *
+ * Flags for an operation to download or update apps.
+ *
+ * Since: 44
+ */
+typedef enum {
+	GS_PLUGIN_UPDATE_APPS_FLAGS_NONE = 0,
+	GS_PLUGIN_UPDATE_APPS_FLAGS_INTERACTIVE = 1 << 0,
+	GS_PLUGIN_UPDATE_APPS_FLAGS_NO_DOWNLOAD = 1 << 1,
+	GS_PLUGIN_UPDATE_APPS_FLAGS_NO_APPLY = 1 << 2,
+} GsPluginUpdateAppsFlags;
+
+/**
+ * GsPluginCancelOfflineUpdateFlags:
+ * @GS_PLUGIN_CANCEL_OFFLINE_UPDATE_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_CANCEL_OFFLINE_UPDATE_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for an operation to cancel a pending offline update.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_CANCEL_OFFLINE_UPDATE_FLAGS_NONE		= 0,
+	GS_PLUGIN_CANCEL_OFFLINE_UPDATE_FLAGS_INTERACTIVE	= 1 << 0,
+} GsPluginCancelOfflineUpdateFlags;
+
+/**
+ * GsPluginDownloadUpgradeFlags:
+ * @GS_PLUGIN_DOWNLOAD_UPGRADE_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_DOWNLOAD_UPGRADE_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for an operation to download an upgrade.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_DOWNLOAD_UPGRADE_FLAGS_NONE		= 0,
+	GS_PLUGIN_DOWNLOAD_UPGRADE_FLAGS_INTERACTIVE	= 1 << 0,
+} GsPluginDownloadUpgradeFlags;
+
+/**
+ * GsPluginTriggerUpgradeFlags:
+ * @GS_PLUGIN_TRIGGER_UPGRADE_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_TRIGGER_UPGRADE_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for an operation to trigger an upgrade.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_TRIGGER_UPGRADE_FLAGS_NONE		= 0,
+	GS_PLUGIN_TRIGGER_UPGRADE_FLAGS_INTERACTIVE	= 1 << 0,
+} GsPluginTriggerUpgradeFlags;
+
+/**
+ * GsPluginLaunchFlags:
+ * @GS_PLUGIN_LAUNCH_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_LAUNCH_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for a launch operation.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_LAUNCH_FLAGS_NONE		= 0,
+	GS_PLUGIN_LAUNCH_FLAGS_INTERACTIVE	= 1 << 0,
+} GsPluginLaunchFlags;
+
+/**
+ * GsPluginFileToAppFlags:
+ * @GS_PLUGIN_FILE_TO_APP_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_FILE_TO_APP_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for a file-to-app operation.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_FILE_TO_APP_FLAGS_NONE	= 0,
+	GS_PLUGIN_FILE_TO_APP_FLAGS_INTERACTIVE	= 1 << 0,
+} GsPluginFileToAppFlags;
+
+/**
+ * GsPluginUrlToAppFlags:
+ * @GS_PLUGIN_URL_TO_APP_FLAGS_NONE: No flags set.
+ * @GS_PLUGIN_URL_TO_APP_FLAGS_INTERACTIVE: User initiated the job.
+ *
+ * Flags for a url-to-app operation.
+ *
+ * Since: 47
+ */
+typedef enum {
+	GS_PLUGIN_URL_TO_APP_FLAGS_NONE	= 0,
+	GS_PLUGIN_URL_TO_APP_FLAGS_INTERACTIVE	= 1 << 0,
+} GsPluginUrlToAppFlags;
+
+/**
+ * GsPluginProgressCallback:
+ * @plugin: the #GsPlugin reporting its progress
+ * @progress: the percentage completion (0–100 inclusive), or
+ *   %GS_APP_PROGRESS_UNKNOWN for unknown
+ * @user_data: user data passed to the calling function
+ *
+ * Callback to report the progress of a particular @plugin through a particular
+ * operation.
+ *
+ * Since: 44
+ */
+typedef void (* GsPluginProgressCallback)		(GsPlugin	*plugin,
+							 guint		 progress,
+							 gpointer	 user_data);
+
+/**
+ * GsPluginAppNeedsUserActionCallback:
+ * @plugin: the #GsPlugin asking for user action
+ * @app: (nullable) (transfer none): the related #GsApp, or %NULL if no app is
+ *   explicitly related to the necessary user action
+ * @action_screenshot: (nullable) (transfer none): a screenshot (with caption
+ *   set) which gives the user instructions about what action to take, or %NULL
+ *   if no instructions are available
+ * @user_data: user data passed to the calling function
+ *
+ * Callback to ask the user to perform a physical action during a plugin
+ * operation.
+ *
+ * This will typically be something like unplugging and reconnecting a hardware
+ * device, and instructions will be given via @action_screenshot.
+ *
+ * Since: 44
+ */
+typedef void (* GsPluginAppNeedsUserActionCallback)	(GsPlugin	*plugin,
+							 GsApp		*app,
+							 AsScreenshot	*action_screenshot,
+							 gpointer	 user_data);
+
 /**
  * GsPluginRule:
  * @GS_PLUGIN_RULE_CONFLICTS:		The plugin conflicts with another
@@ -272,19 +449,11 @@ typedef enum {
 /**
  * GsPluginAction:
  * @GS_PLUGIN_ACTION_UNKNOWN:			Action is unknown
- * @GS_PLUGIN_ACTION_INSTALL:			Install an application
- * @GS_PLUGIN_ACTION_REMOVE:			Remove an application
- * @GS_PLUGIN_ACTION_UPDATE:			Update an application
+ * @GS_PLUGIN_ACTION_INSTALL:			Install an app
  * @GS_PLUGIN_ACTION_UPGRADE_DOWNLOAD:		Download a distro upgrade
- * @GS_PLUGIN_ACTION_UPGRADE_TRIGGER:		Trigger a distro upgrade
- * @GS_PLUGIN_ACTION_LAUNCH:			Launch an application
- * @GS_PLUGIN_ACTION_UPDATE_CANCEL:		Cancel the update
- * @GS_PLUGIN_ACTION_GET_UPDATES:		Get the list of updates
- * @GS_PLUGIN_ACTION_GET_SOURCES:		Get the list of sources
- * @GS_PLUGIN_ACTION_FILE_TO_APP:		Convert the file to an application
- * @GS_PLUGIN_ACTION_URL_TO_APP:		Convert the URI to an application
- * @GS_PLUGIN_ACTION_GET_UPDATES_HISTORICAL:    Get the list of historical updates
- * @GS_PLUGIN_ACTION_DOWNLOAD:			Download an application
+ * @GS_PLUGIN_ACTION_LAUNCH:			Launch an app
+ * @GS_PLUGIN_ACTION_FILE_TO_APP:		Convert the file to an app
+ * @GS_PLUGIN_ACTION_URL_TO_APP:		Convert the URI to an app
  * @GS_PLUGIN_ACTION_GET_LANGPACKS:		Get appropriate language pack
  * @GS_PLUGIN_ACTION_INSTALL_REPO:		Install a repository (Since: 41)
  * @GS_PLUGIN_ACTION_REMOVE_REPO:		Remove a repository (Since: 41)
@@ -296,18 +465,10 @@ typedef enum {
 typedef enum {
 	GS_PLUGIN_ACTION_UNKNOWN,
 	GS_PLUGIN_ACTION_INSTALL,
-	GS_PLUGIN_ACTION_REMOVE,
-	GS_PLUGIN_ACTION_UPDATE,
 	GS_PLUGIN_ACTION_UPGRADE_DOWNLOAD,
-	GS_PLUGIN_ACTION_UPGRADE_TRIGGER,
 	GS_PLUGIN_ACTION_LAUNCH,
-	GS_PLUGIN_ACTION_UPDATE_CANCEL,
-	GS_PLUGIN_ACTION_GET_UPDATES,
-	GS_PLUGIN_ACTION_GET_SOURCES,
 	GS_PLUGIN_ACTION_FILE_TO_APP,
 	GS_PLUGIN_ACTION_URL_TO_APP,
-	GS_PLUGIN_ACTION_GET_UPDATES_HISTORICAL,
-	GS_PLUGIN_ACTION_DOWNLOAD,
 	GS_PLUGIN_ACTION_GET_LANGPACKS,
 	GS_PLUGIN_ACTION_INSTALL_REPO,
 	GS_PLUGIN_ACTION_REMOVE_REPO,
