@@ -77,7 +77,7 @@ gs_loading_page_job_progress_cb (GsPluginJobRefreshMetadata *plugin_job,
 	/* update title */
 	adw_status_page_set_title (ADW_STATUS_PAGE (priv->status_page),
 				   /* TRANSLATORS: initial start */
-				   _("Downloading Software Catalog"));
+				   _("Refreshing Data"));
 
 	/* update progressbar */
 	stop_progress_pulse (self);
